==> pmml-model-gwt-1.3.9.jar: org/dmg/pmml/MatCell.java <==

package org.dmg.pmml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.XmlValue;
import org.eclipse.persistence.oxm.annotations.XmlValueExtension;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;simpleContent>
 *     &lt;extension base="&lt;http://www.w3.org/2001/XMLSchema>string">
 *       &lt;attribute name="row" use="required" type="{http://www.dmg.org/PMML-4_3}INT-NUMBER" />
 *       &lt;attribute name="col" use="required" type="{http://www.dmg.org/PMML-4_3}INT-NUMBER" />
 *     &lt;/extension>
 *   &lt;/simpleContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "value"
})
@XmlRootElement(name = "MatCell", namespace = "http://www.dmg.org/PMML-4_3")
public class MatCell
    extends PMMLObject
{

    @XmlAttribute(name = "row", required = true)
    private int row;
    @XmlAttribute(name = "col", required = true)
    private int col;
    @XmlValue
    @XmlValueExtension
    private String value;
    private final static long serialVersionUID = 67305479L;

    public MatCell() {
    }

    public MatCell(
        @org.jpmml.model.Property("row")
        int row,
        @org.jpmml.model.Property("col")
        int col,
        @org.jpmml.model.Property("value")
        String value) {
        this.row = row;
        this.col = col;
        this.value = value;
    }

    /**
     * Gets the value of the row property.
     * 
     */
    public int getRow() {
        return row;
    }

    /**
     * Sets the value of the row property.
     * 
     */
    public MatCell setRow(
        @org.jpmml.model.Property("row")
        int row) {
        this.row = row;
        return this;
    }

    /**
     * Gets the value of the col property.
     * 
     */
    public int getCol() {
        return col;
    }

    /**
     * Sets the value of the col property.
     * 
     */
    public MatCell setCol(
        @org.jpmml.model.Property("col")
        int col) {
        this.col = col;
        return this;
    }

    /**
     * Gets the value of the value property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getValue() {
        return value;
    }

    /**
     * Sets the value of the value property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public MatCell setValue(
        @org.jpmml.model.Property("value")
        String value) {
        this.value = value;
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-gwt-1.4.5.jar: org/dmg/pmml/MatCell.java <==

package org.dmg.pmml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.XmlValue;
import org.eclipse.persistence.oxm.annotations.XmlValueExtension;

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "value"
})
@XmlRootElement(name = "MatCell", namespace = "http://www.dmg.org/PMML-4_3")
public class MatCell
    extends PMMLObject
{

    @XmlAttribute(name = "row", required = true)
    private int row;
    @XmlAttribute(name = "col", required = true)
    private int col;
    @XmlValue
    @XmlValueExtension
    private String value;
    private final static long serialVersionUID = 67305483L;

    public MatCell() {
    }

    public MatCell(
        @org.jpmml.model.annotations.Property("row")
        int row,
        @org.jpmml.model.annotations.Property("col")
        int col,
        @org.jpmml.model.annotations.Property("value")
        String value) {
        this.row = row;
        this.col = col;
        this.value = value;
    }

    public int getRow() {
        return row;
    }

    public MatCell setRow(
        @org.jpmml.model.annotations.Property("row")
        int row) {
        this.row = row;
        return this;
    }

    public int getCol() {
        return col;
    }

    public MatCell setCol(
        @org.jpmml.model.annotations.Property("col")
        int col) {
        this.col = col;
        return this;
    }

    public String getValue() {
        return value;
    }

    public MatCell setValue(
        @org.jpmml.model.annotations.Property("value")
        String value) {
        this.value = value;
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
